from .micral_name import nameImage

from os.path import realpath, dirname
def version():
	try:
		with open(dirname(realpath(__file__))+'/version.txt') as f:
			return f.read()
	except:
		return "0.0.0"

def analyse(images, plot=False):
    return nameImage(images, plot)


from setuptools import setup

def version():
	try:
		with open('version.txt') as f:
			return f.read()
	except:
		return "0.0.0"

def readme():
	try:
		with open('README.rst') as f:
			return f.read()
	except:
		return "Can't read README.rst"

setup(name='micral_name',
      version=version(),
      description='Name tool between 7 available',
      long_description=readme(),
      author='Yann LEROY',
      author_email='yann.leroy102@orange.fr',
      license='MIT',
      packages=['micral_name'],
	  install_requires=[
		'micral_name_core'
      ],
	  include_package_data=True,
      zip_safe=False)


import micral_name_core

def namePrint(dict_input, plot):
    output_coarse = dict()
    if dict_input != None:
        for nameImg, dictImg in dict_input.items():
            if 'name' in dictImg:
                output_coarse[nameImg] = dictImg['name']
            
    return output_coarse

def nameImage(images, plot):
    out = micral_name_core.analyse(images, plot)
    return namePrint(out, plot)